@@ -38,7 +38,7 @@
  *
  * Since: 1.0.0
  */
-#define GGANDIVA_VERSION_MAJOR (19)
+#define GGANDIVA_VERSION_MAJOR (20)
 
 /**
  * GGANDIVA_VERSION_MINOR:
@@ -110,6 +110,15 @@
 #  define GGANDIVA_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GGANDIVA_VERSION_20_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 20.0.0
+ */
+#define GGANDIVA_VERSION_20_0 G_ENCODE_VERSION(20, 0)
+
 /**
  * GGANDIVA_VERSION_19_0:
  *
@@ -415,6 +424,20 @@
 
 #define GGANDIVA_AVAILABLE_IN_ALL GGANDIVA_EXTERN
 
+#if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_20_0
+#  define GGANDIVA_DEPRECATED_IN_20_0               GGANDIVA_DEPRECATED
+#  define GGANDIVA_DEPRECATED_IN_20_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
+#else
+#  define GGANDIVA_DEPRECATED_IN_20_0
+#  define GGANDIVA_DEPRECATED_IN_20_0_FOR(function)
+#endif
+
+#if GGANDIVA_VERSION_MAX_ALLOWED < GGANDIVA_VERSION_20_0
+#  define GGANDIVA_AVAILABLE_IN_20_0 GGANDIVA_EXTERN GGANDIVA_UNAVAILABLE(20, 0)
+#else
+#  define GGANDIVA_AVAILABLE_IN_20_0 GGANDIVA_EXTERN
+#endif
+
 #if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_19_0
 #  define GGANDIVA_DEPRECATED_IN_19_0               GGANDIVA_DEPRECATED
 #  define GGANDIVA_DEPRECATED_IN_19_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
